@@ -1,18 +1,18 @@
 /* Formatted output to a stream.
-   Copyright (C) 2004, 2006-2016 Free Software Foundation, Inc.
+   Copyright (C) 2004, 2006-2021 Free Software Foundation, Inc.
 
-   This program is free software: you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
-   (at your option) any later version.
+   This file is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation; either version 3 of the
+   License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -52,11 +52,7 @@ vfprintf (FILE *fp, const char *format, va_list args)
   if (fwrite (output, 1, len, fp) < len)
     {
       if (output != buf)
-        {
-          int saved_errno = errno;
-          free (output);
-          errno = saved_errno;
-        }
+        free (output);
       return -1;
     }
 
